package org.greenstone.gsdl3.core;

import org.greenstone.gsdl3.util.*;
import org.greenstone.gsdl3.action.*;
// XML classes
import org.w3c.dom.Node; 
import org.w3c.dom.NodeList; 
import org.w3c.dom.Document; 
import org.w3c.dom.Element; 

// other java classes
import java.io.File;
import java.util.HashMap;
import java.util.Enumeration;

/** 
 * This is a new version of the Receptionist for the NZDL interface
 * the interface requires a lot more info for each page
 * @see DefaultReceptionist
 */
public class NZDLReceptionist extends DefaultReceptionist {
    
    protected void addExtraInfo(Element page) {
	///ystem.out.println("the  page before adding extra info is");
	///ystem.out.println(this.converter.getPrettyString(page));

	super.addExtraInfo(page);

	// this gets the collection info
	Element page_response = (Element)GSXML.getChildByTagName(page, GSXML.PAGE_RESPONSE_ELEM);
	Element page_request = (Element)GSXML.getChildByTagName(page, GSXML.PAGE_REQUEST_ELEM);
	Element collection_info = (Element)GSXML.getChildByTagName(page_response, GSXML.COLLECTION_ELEM);
	if (collection_info== null) {
	    return;
	}

	String collection = collection_info.getAttribute("name"); // should we take this from the request instead??
	// look through services and see if classifier one is present - need to
	// get the list of classifiers
	Element service_list = (Element)GSXML.getChildByTagName(collection_info, GSXML.SERVICE_ELEM+GSXML.LIST_MODIFIER);
	if (service_list == null) {
	    // something weird has gone wrong
	    return;
	}
	
	Element info_message = this.doc.createElement(GSXML.MESSAGE_ELEM);
	String lang = page.getAttribute(GSXML.LANG_ATT);
	
	boolean do_classifier = false;
	boolean do_query = false;
	Element classifier_service = GSXML.getNamedElement(service_list, GSXML.SERVICE_ELEM, GSXML.NAME_ATT, "ClassifierBrowse");
	Element query_service = GSXML.getNamedElement(service_list, GSXML.SERVICE_ELEM, GSXML.NAME_ATT, "TextQuery");
	if (classifier_service != null) {
	    do_classifier = true;
	    // find the list of classifiers
	
	    String to = GSPath.appendLink(collection, "ClassifierBrowse");
	    Element info_request = GSXML.createBasicRequest(this.doc, GSXML.REQUEST_TYPE_DESCRIBE, to, lang, ""); 
	    info_message.appendChild(info_request);
	}
	
	String action = page_request.getAttribute(GSXML.ACTION_ATT);
	String subaction = page_request.getAttribute(GSXML.SUBACTION_ATT);
	
	if (query_service != null && action.equals("p") && subaction.equals("about")) {
	    do_query = true;
	    // get the full description
	    String to = GSPath.appendLink(collection, "TextQuery");
	    Element query_request = GSXML.createBasicRequest(this.doc, GSXML.REQUEST_TYPE_DESCRIBE, to, lang, "");
	    info_message.appendChild(query_request);
	    
	}
	
	Element info_resp_message = (Element) this.mr.process(info_message);
	Element info_response = (Element) GSXML.getChildByTagName(info_resp_message, GSXML.RESPONSE_ELEM); 
	//	String path = GSPath.appendLink(GSXML.RESPONSE_ELEM, GSXML.SERVICE_ELEM);
	if (do_classifier) {
	    Element classifier_service_info = (Element)GSXML.getNamedElement(info_response, GSXML.SERVICE_ELEM, GSXML.NAME_ATT, "CLassifierBrowse");
	    if (classifier_service_info != null) {
		service_list.replaceChild(this.doc.importNode(classifier_service_info, true), classifier_service);
	    }
	}
	if (do_query) {
	    Element query_service_info = (Element)GSXML.getNamedElement(info_response, GSXML.SERVICE_ELEM, GSXML.NAME_ATT, "TextQuery");
	    if (query_service_info != null) {
		service_list.replaceChild(this.doc.importNode(query_service_info, true), query_service);
	    }
	}
	///ystem.out.println("the final page before transforming is");
	///ystem.out.println(this.converter.getPrettyString(page));
	return;
    }
	
}
    
